@@ -48,10 +48,10 @@
 #'          \describe{
 #'            \item{\code{type = "cond"}}{(default) plots the mere change of the moderating effect on the response value (conditional effect). See 'Details'.}
 #'            \item{\code{type = "eff"}}{plots the overall moderation effect on the response value. See 'Details'.}
-#'            \item{\code{type = "emm"}}{plots the estimated marginal means (least square means). If this type is chosen, not all function parameters are applicable. See 'Details'.}
+#'            \item{\code{type = "emm"}}{plots the estimated marginal means (least square means). If this type is chosen, not all function arguments are applicable. See 'Details'.}
 #'          }
 #' @param int.term select interaction term of \code{fit} (as character), which should be plotted
-#'          when using \code{type = "eff"}. By default, this parameter can be ignored
+#'          when using \code{type = "eff"}. By default, this argument can be ignored
 #'          (i.e. \code{int.term = NULL}). See 'Details'.
 #' @param int.plot.index numeric vector with index numbers that indicate which 
 #'          interaction terms should be plotted in case the \code{fit} has more than
@@ -76,7 +76,7 @@
 #' @param plevel indicates at which p-value an interaction term is considered as \emph{significant},
 #'          i.e. at which p-level an interaction term will be considered for plotting. Default is
 #'          0.05 (5 percent), hence, non-significant interactions are excluded by default. This
-#'          parameter does not apply to \code{type = "eff"}.
+#'          argument does not apply to \code{type = "eff"}.
 #' @param title a default title used for the plots. Should be a character vector
 #'          of same length as interaction plots to be plotted. Default value is \code{NULL}, which means that each plot's title
 #'          includes the dependent variable as well as the names of the interaction terms.
@@ -143,13 +143,13 @@
 #'              Hence, this plot type may be used especially for \emph{binary or dummy coded} 
 #'              moderator values (see also \href{http://jee3.web.rice.edu/interaction-overconfidence.pdf}{Esarey and Summer 2015}).
 #'              This type \emph{does not} show the overall effect of interactions on the result of Y. Use 
-#'              \code{type = "eff"} for effect displays similar to the \code{\link[effects]{effect}} function 
-#'              from the effects-package.
+#'              \code{type = "eff"} for effect displays similar to the \code{\link[effects]{effect}}-function 
+#'              from the \pkg{effects}-package.
 #'            }
-#'            \item{\code{type = "eff"}}{plots the overall effects of the interaction, with all remaining
+#'            \item{\code{type = "eff"}}{plots the overall effects (marginal effects) of the interaction, with all remaining
 #'              covariates set to the mean. Effects are calculated using the \code{\link[effects]{effect}}-
-#'              function from the \code{effects}-package. \cr \cr
-#'              Following parameters \emph{do not} apply to this function: \code{diff}, \code{axisLabels.x}
+#'              function from the \pkg{effects}-package. \cr \cr
+#'              Following arguments \emph{do not} apply to this function: \code{diff}, \code{axisLabels.x}
 #'              \code{interceptLineColor}, \code{estLineColor}, \code{lineLabelSize}, \code{lineLabelColor} 
 #'              and \code{lineLabelString}.
 #'            }
@@ -161,11 +161,11 @@
 #'              to plot differences in interventions between control and treatment groups over multiple time points.
 #'              \itemize{
 #'                \item Following paramters apply to this plot type: \code{showCI}, \code{valueLabel.digits} and \code{axisLabels.x}.
-#'                \item Following parameters \emph{do not} apply to this function: \code{int.term}, \code{int.plot.index}, \code{diff}, \code{moderatorValues}, \code{fillColor}, \code{fillAlpha}, \code{interceptLineColor}, \code{estLineColor}, \code{lineLabelSize}, \code{lineLabelColor} and \code{lineLabelString}.
+#'                \item Following arguments \emph{do not} apply to this function: \code{int.term}, \code{int.plot.index}, \code{diff}, \code{moderatorValues}, \code{fillColor}, \code{fillAlpha}, \code{interceptLineColor}, \code{estLineColor}, \code{lineLabelSize}, \code{lineLabelColor} and \code{lineLabelString}.
 #'              }
 #'            }
 #'          }
-#'          The parameter \code{int.term} only applies to \code{type = "eff"} and can be used
+#'          The argument \code{int.term} only applies to \code{type = "eff"} and can be used
 #'          to select a specific interaction term of the model that should be plotted. The function
 #'          then calls \code{effect(int.term, fit)} to compute effects for this specific interaction
 #'          term only. This approach is recommended, when the fitted model contains many observations
@@ -187,7 +187,7 @@
 #'
 #' # fit "dummy" model. Note that moderator should enter
 #' # first the model, followed by predictor. Else, use
-#' # parameter "swapPredictors" to change predictor on 
+#' # argument "swapPredictors" to change predictor on 
 #' # x-axis with moderator
 #' fit <- lm(weight ~ Diet * Time, data = ChickWeight)
 #'
@@ -253,12 +253,12 @@
 #' # plot interaction, increase p-level sensivity
 #' sjp.int(fit,
 #'         type = "eff",
-#'         legendLabels = get_val_labels(efc$c161sex),
+#'         legendLabels = get_labels(efc$c161sex),
 #'         plevel = 0.1)
 #'
 #' sjp.int(fit,
 #'         type = "cond",
-#'         legendLabels = get_val_labels(efc$c161sex),
+#'         legendLabels = get_labels(efc$c161sex),
 #'         plevel = 0.1)
 #'         
 #' \dontrun{
@@ -279,7 +279,7 @@
 #' # name factor levels and dependent variable
 #' levels(mydf$sex) <- c("female", "male")
 #' levels(mydf$education) <- c("low", "mid", "high")
-#' mydf$burden <- set_var_labels(mydf$burden, "care burden")
+#' mydf$burden <- set_label(mydf$burden, "care burden")
 #' # fit "dummy" model
 #' fit <- lm(burden ~ .*., data = mydf)
 #' summary(fit)
@@ -400,14 +400,14 @@ sjp.int <- function(fit,
     stop("Package 'plm' needs to be loaded for this function to work... Use 'library(plm)' and call this function again.", call. = FALSE)
   }
   # -----------------------------------------------------------
-  # parameter check
+  # argument check
   # -----------------------------------------------------------
   if (is.null(fillColor)) {
     fillColor <- "white"
     fillAlpha <- 0
   }
   # gridbreaks
-  if (is.null(gridBreaksAt)) gridbreaks.x <- gridbreaks.y <- waiver()
+  if (is.null(gridBreaksAt)) gridbreaks.x <- gridbreaks.y <- ggplot2::waiver()
   # moderator value
   if (moderatorValues != "minmax" && moderatorValues != "zeromax" && moderatorValues != "meansd" && moderatorValues != "quart") {
     message("'moderatorValues' has to be one of 'minmax', 'zeromax', 'quart' or 'meansd'. Defaulting to 'minmax'...")
@@ -949,7 +949,7 @@ sjp.eff.int <- function(fit,
     stop("Package 'effects' needed for this function to work. Please install it.", call. = FALSE)
   }
   # gridbreaks
-  if (is.null(gridBreaksAt)) gridbreaks.x <- gridbreaks.y <- waiver()
+  if (is.null(gridBreaksAt)) gridbreaks.x <- gridbreaks.y <- ggplot2::waiver()
   # ------------------------
   # calculate effects of higher order terms and
   # check if fitted model contains any interaction terms
@@ -1454,7 +1454,7 @@ getInteractionTerms <- function(fit, fun, plevel) {
   }
   # check for any signigicant interactions, stop if nothing found
   if (is.null(intnames)) {
-    warning("No significant interactions found... Try to adjust 'plevel'-parameter.", call. = FALSE)
+    warning("No significant interactions found... Try to adjust 'plevel' argument.", call. = FALSE)
     return(invisible(NULL))
   }
   return(list(intnames = intnames,
