@@ -27,7 +27,7 @@
 #'          first column/row. If no item labels are provided (default), the 
 #'          data frame's column names are used. Item labels are detected automatically 
 #'          if \code{data} is a \code{\link{data.frame}} where variables have
-#'          label attributes (see \code{\link[sjmisc]{set_var_labels}}) for details).
+#'          label attributes (see \code{\link[sjmisc]{set_label}}) for details).
 #' @param digits amount of digits used the values inside table cells.
 #'          Default is 2.
 #' @param triangle indicates whether only the upper right (use \code{"upper"}), lower left (use \code{"lower"})
@@ -36,15 +36,15 @@
 #' @param val.rm specify a number between 0 and 1 to suppress the output of correlation values 
 #'          that are smaller than \code{val.rm}. The absolute correlation values are used, so
 #'          a correlation value of \code{-.5} would be greater than \code{val.rm = .4} and thus not be
-#'          omitted. By default, this parameter is \code{NULL}, hence all values are shown in the table.
+#'          omitted. By default, this argument is \code{NULL}, hence all values are shown in the table.
 #'          If a correlation value is below the specified value of \code{val.rm}, it is still printed to
 #'          the HTML table, but made "invisible" with white foreground color. You can use the \code{CSS}
-#'          parameter (\code{"css.valueremove"}) to change color and appearance of those correlation value that are smaller than
+#'          argument (\code{"css.valueremove"}) to change color and appearance of those correlation value that are smaller than
 #'          the limit specified by \code{val.rm}. 
 #' @param stringDiagonal a vector with string values of the same length as \code{ncol(data)} (number of
 #'          correlated items) that can be used to display content in the diagonal cells
 #'          where row and column item are identical (i.e. the "self-correlation"). By defauilt,
-#'          this parameter is \code{NULL} and the diagnal cells are empty.
+#'          this argument is \code{NULL} and the diagnal cells are empty.
 #'          
 #' @inheritParams sjt.frq
 #' @inheritParams sjt.df
@@ -87,7 +87,7 @@
 #' data(efc)
 #' 
 #' # retrieve variable and value labels
-#' varlabs <- get_var_labels(efc)
+#' varlabs <- get_label(efc)
 #' 
 #' # recveive first item of COPE-index scale
 #' start <- which(colnames(efc) == "c83cop2")
@@ -161,7 +161,7 @@ sjt.corr <- function(data,
   # --------------------------------------------------------
   encoding <- get.encoding(encoding)
   # --------------------------------------------------------
-  # parameter check
+  # argument check
   # --------------------------------------------------------
   if (is.null(triangle)) {
     triangle <- "both"
@@ -171,7 +171,7 @@ sjt.corr <- function(data,
     triangle <- "lower"
   } else triangle <- "both"
   # --------------------------------------------------------
-  # try to automatically set labels is not passed as parameter
+  # try to automatically set labels is not passed as argument
   # --------------------------------------------------------
   if (is.null(varlabels) && is.data.frame(data)) {
     varlabels <- c()
@@ -190,10 +190,10 @@ sjt.corr <- function(data,
     }
   }
   # ----------------------------
-  # check for valid parameter
+  # check for valid argument
   # ----------------------------
   if (corMethod != "pearson" && corMethod != "spearman" && corMethod != "kendall") {
-    stop("Parameter 'corMethod' must be one of: pearson, spearman or kendall")
+    stop("argument 'corMethod' must be one of: pearson, spearman or kendall")
   }
   # ----------------------------
   # check if user has passed a data frame
@@ -216,7 +216,7 @@ sjt.corr <- function(data,
                   use = "pairwise.complete.obs")
     }
     #---------------------------------------
-    # if we have a data frame as parameter,
+    # if we have a data frame as argument,
     # compute p-values of significances
     #---------------------------------------
     computePValues <- function(df) {
@@ -250,10 +250,7 @@ sjt.corr <- function(data,
       # with asterisks
       # --------------------------------------------------------
       fun.star <- function(x) {
-        if (x >= 0.05) x <- ""
-        else if (x >= 0.01 && x < 0.05) x <- "*"
-        else if (x >= 0.001 && x < 0.01) x <- "**"
-        else if (x < 0.001) x <- "***"
+        x <- get_p_stars(x)
       }
     } else {
       # --------------------------------------------------------
@@ -476,20 +473,20 @@ sjt.corr <- function(data,
   # -------------------------------------
   # set style attributes for main table tags
   # -------------------------------------
-  knitr <- gsub("class=", "style=", knitr, fixed = TRUE)
-  knitr <- gsub("<table", sprintf("<table style=\"%s\"", css.table), knitr, fixed = TRUE)
-  knitr <- gsub("<caption", sprintf("<caption style=\"%s\"", css.caption), knitr, fixed = TRUE)
+  knitr <- gsub("class=", "style=", knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub("<table", sprintf("<table style=\"%s\"", css.table), knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub("<caption", sprintf("<caption style=\"%s\"", css.caption), knitr, fixed = TRUE, useBytes = TRUE)
   # -------------------------------------
   # replace class-attributes with inline-style-definitions
   # -------------------------------------
-  knitr <- gsub(tag.tdata, css.tdata, knitr, fixed = TRUE)
-  knitr <- gsub(tag.thead, css.thead, knitr, fixed = TRUE)
-  knitr <- gsub(tag.centeralign, css.centeralign, knitr, fixed = TRUE)
-  knitr <- gsub(tag.notsig, css.notsig, knitr, fixed = TRUE)  
-  knitr <- gsub(tag.pval, css.pval, knitr, fixed = TRUE)  
-  knitr <- gsub(tag.summary, css.summary, knitr, fixed = TRUE)  
-  knitr <- gsub(tag.firsttablecol, css.firsttablecol, knitr, fixed = TRUE)  
-  knitr <- gsub(tag.valueremove, css.valueremove, knitr, fixed = TRUE)  
+  knitr <- gsub(tag.tdata, css.tdata, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.thead, css.thead, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.centeralign, css.centeralign, knitr, fixed = TRUE, useBytes = TRUE)
+  knitr <- gsub(tag.notsig, css.notsig, knitr, fixed = TRUE, useBytes = TRUE)  
+  knitr <- gsub(tag.pval, css.pval, knitr, fixed = TRUE, useBytes = TRUE)  
+  knitr <- gsub(tag.summary, css.summary, knitr, fixed = TRUE, useBytes = TRUE)  
+  knitr <- gsub(tag.firsttablecol, css.firsttablecol, knitr, fixed = TRUE, useBytes = TRUE)  
+  knitr <- gsub(tag.valueremove, css.valueremove, knitr, fixed = TRUE, useBytes = TRUE)  
   # -------------------------------------
   # remove spaces?
   # -------------------------------------
